internal_data: Internal distribution parameter tables for percentile curve...

internal_dataR Documentation

Internal distribution parameter tables for percentile curve models to derive z-scores used by the scoring system

Description

These datasets provide the distribution parameters (e.g., mu, sigma, nu, tau) used internally for score calculation across different variables and sex categories.

Usage

par_bmi_boys

par_bmi_girls

par_waist_boys

par_waist_girls

par_MetS_shifted_boys

par_MetS_shifted_girls

par_sbp_boys

par_sbp_girls

par_dbp_boys

par_dbp_girls

par_glu_boys

par_glu_girls

par_hdl_boys

par_hdl_girls

par_height_boys

par_height_girls

par_homa_boys

par_homa_girls

par_insu_boys

par_insu_girls

par_trg_boys

par_trg_girls

par_crp_girls

par_crp_boys

Format

A data frame containing distribution parameters for each variable and sex.

An object of class data.frame with 91 rows and 5 columns.

An object of class data.frame with 90 rows and 6 columns.

An object of class data.frame with 90 rows and 6 columns.

An object of class data.frame with 80 rows and 5 columns.

An object of class data.frame with 80 rows and 5 columns.

An object of class data.frame with 2411 rows and 7 columns.

An object of class data.frame with 2385 rows and 7 columns.

An object of class data.frame with 2411 rows and 7 columns.

An object of class data.frame with 2385 rows and 7 columns.

An object of class data.frame with 80 rows and 4 columns.

An object of class data.frame with 80 rows and 4 columns.

An object of class data.frame with 90 rows and 6 columns.

An object of class data.frame with 90 rows and 6 columns.

An object of class data.frame with 90 rows and 6 columns.

An object of class data.frame with 90 rows and 6 columns.

An object of class data.frame with 80 rows and 6 columns.

An object of class data.frame with 80 rows and 6 columns.

An object of class data.frame with 80 rows and 6 columns.

An object of class data.frame with 80 rows and 6 columns.

An object of class data.frame with 90 rows and 5 columns.

An object of class data.frame with 90 rows and 5 columns.

An object of class data.frame with 2151 rows and 7 columns.

An object of class data.frame with 2151 rows and 7 columns.

Details

Not intended for direct use by end users.


pediatric.zcalc documentation built on Sept. 30, 2026, 5:13 p.m.