p_hurdle: Calculate Percentile Ranks for the Hurdle Model

View source: R/score_calculator.R

p_hurdleR Documentation

Calculate Percentile Ranks for the Hurdle Model

Description

Computes individual percentile ranks using a hurdle model described by p1, mu, sigma, nu, and tau by combining the probability from the first part of the hurdle model ('p1') with the conditional distribution of the second part.

Usage

p_hurdle(y, p1, mu, sigma, nu, tau)

Arguments

y

Numeric vector. Observed values of the variable to assess.

p1

Numeric vector. Probability from the first part of the hurdle model.

mu

Numeric vector. Location parameter of the continuous distribution.

sigma

Numeric vector. Scale parameter of the continuous distribution.

nu

Numeric vector. Shape parameter of the continuous distribution.

tau

Numeric vector. Tail parameter of the continuous distribution.

Value

A numeric vector of the same length as 'y' containing the calculated individual percentile ranks.


pediatric.zcalc documentation built on Sept. 30, 2026, 5:13 p.m.