View source: R/score_calculator.R
| p_hurdle | R Documentation |
Computes individual percentile ranks using a hurdle model described by p1, mu, sigma, nu, and tau by combining the probability from the first part of the hurdle model ('p1') with the conditional distribution of the second part.
p_hurdle(y, p1, mu, sigma, nu, tau)
y |
Numeric vector. Observed values of the variable to assess. |
p1 |
Numeric vector. Probability from the first part of the hurdle model. |
mu |
Numeric vector. Location parameter of the continuous distribution. |
sigma |
Numeric vector. Scale parameter of the continuous distribution. |
nu |
Numeric vector. Shape parameter of the continuous distribution. |
tau |
Numeric vector. Tail parameter of the continuous distribution. |
A numeric vector of the same length as 'y' containing the calculated individual percentile ranks.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.